package com.jz.dmp.modules.controller.dataService;

import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.dmp.modules.controller.dataService.bean.*;
import com.jz.dmp.modules.service.DmpApiMangeService;
import com.jz.dmp.modules.service.DmpApiServiceMangeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 数据服务-服务管理--调用gateway 接口
 *
 * @author Bellamy
 * @since 2021-01-18 10:56:18
 */
@RestController
@RequestMapping("/apiService")
@Api(tags = "数据服务-服务管理")
public class DmpApiServiceMangeController {

    private static Logger logger = LoggerFactory.getLogger(DmpApiServiceMangeController.class);

    /**
     * 服务对象
     */
    @Autowired
    private DmpApiServiceMangeService dmpApiServiceMangeService;

    /**
     * 保存API(第三方)基本信息
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @ApiOperation(value = "保存API(第三方)", notes = "保存API(第三方)")
    @PostMapping(value = "/saveApi")
    public JsonResult saveApiInfo(@RequestBody @Validated ApiInterfaceReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.saveApiInfo(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 保存API(大数据查询/标签查询)
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @ApiOperation(value = "保存API(大数据查询/标签查询)", notes = "保存API(大数据查询/标签查询)")
    @PostMapping(value = "/saveApiBigData")
    public JsonResult saveApiBigDataInfo(@RequestBody @Validated MakeBigDataApiReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.saveApiBigDataInfo(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 编辑API(第三方)基本信息
     *
     * @author Bellamy
     * @since 2021-01-20
     */
    @ApiOperation(value = "编辑API(第三方)", notes = "编辑API(第三方)")
    @PostMapping(value = "/updataApi")
    public JsonResult updateApiInfo(@RequestBody @Validated ApiInterfaceReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.updateApiInfo(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 编辑API(大数据查询/标签查询)
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @ApiOperation(value = "编辑API(大数据查询/标签查询)", notes = "编辑API(大数据查询/标签查询)")
    @PostMapping(value = "/updateApiBigData")
    public JsonResult updateApiBigDataInfo(@RequestBody @Validated MakeBigDataApiReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.updateApiBigDataInfo(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

}